==> gallery_1.5.orig.tar.gz: gallery-1.5.orig/locale/he_IL.utf8/he_IL.utf8-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: he_IL.utf8-nls.php,v 1.5.2.3 2005/03/23 08:54:38 cryptographite Exp $
 *
 * Version: 1.5
 */
/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */


/**
 ** Native languagename
 **/
	$nls['language']['he_IL.utf8'] = 		'&#1506;&#1489;&#1512;&#1497;&#1514; (UTF-8)';

/**
 ** Alias for languages which we substitte or send by NUKE or GeekLog
 **/

	$nls['alias']['he_HE'] = 		'he_IL.utf8' ;
	$nls['alias']['he_IL.utf-8'] =		'he_IL.utf8' ;
	$nls['alias']['hebrew'] = 		'he_IL.utf8' ;

/**
 ** Charset
 **/	
	
	$nls['charset']['he_IL.utf8'] = 		'UTF-8';

/**
 ** Direction
 **/
	
	$nls['direction']['he_IL.utf8'] = 		'rtl' ;

/**
 ** Alignment
 **/
	
	$nls['alignment']['he_IL.utf8'] =		'right' ;
?>

==> gallery_1.5.1.orig.tar.gz: gallery-1.5.1.orig/locale/he_IL.utf8/he_IL.utf8-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: he_IL.utf8-nls.php,v 1.9.2.1 2005/09/12 22:40:56 dmolavi Exp $
 *
 * Version: 1.5.1
 */
/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */


/**
 ** Native languagename
 **/
	$nls['language']['he_IL.utf8'] = 		'&#1506;&#1489;&#1512;&#1497;&#1514; (UTF-8)';

/**
 ** Alias for languages which we substitte or send by NUKE or GeekLog
 **/

	$nls['alias']['he_HE'] = 		'he_IL.utf8' ;
	$nls['alias']['he_IL.utf-8'] =		'he_IL.utf8' ;
	$nls['alias']['hebrew'] = 		'he_IL.utf8' ;

/**
 ** Charset
 **/	
	
	$nls['charset']['he_IL.utf8'] = 		'UTF-8';

/**
 ** Direction
 **/
	
	$nls['direction']['he_IL.utf8'] = 		'rtl' ;

/**
 ** Alignment
 **/
	
	$nls['alignment']['he_IL.utf8'] =		'right' ;
?>
